@@ -80,12 +80,13 @@ typedef struct
 
 typedef enum
 {
-	TOTEM_PLUGIN_ERROR_ACTIVATION,
+	TOTEM_PLUGIN_ERROR_ACTIVATION
 } TotemPluginError;
 
-#define TOTEM_PLUGIN_ERROR (totem_plugin_error_quark ())
-
-GQuark totem_plugin_error_quark (void);
+GType totem_plugin_error_get_type	(void);
+GQuark totem_plugin_error_quark 	(void);
+#define TOTEM_TYPE_PLUGIN_ERROR		(totem_remote_command_get_type())
+#define TOTEM_PLUGIN_ERROR		(totem_plugin_error_quark ())
 
 /*
  * Public methods
@@ -105,6 +106,12 @@ GtkWidget	*totem_plugin_create_configure_dialog
 char *		 totem_plugin_find_file		(TotemPlugin *plugin,
 						 const char *file);
 
+GtkBuilder *     totem_plugin_load_interface    (TotemPlugin *plugin,
+						 const char *name,
+						 gboolean fatal,
+						 GtkWindow *parent,
+						 gpointer user_data);
+
 GList *          totem_get_plugin_paths            (void);
 
 /*
@@ -122,7 +129,7 @@ GList *          totem_get_plugin_paths            (void);
 #define _TOTEM_PLUGIN_REGISTER_EXTENDED_BEGIN(PluginName, plugin_name)		\
 										\
 static GType plugin_name##_type = 0;						\
-static GTypeModule *plugin_module_type = 0;		                	\
+static GTypeModule *plugin_module_type = NULL;					\
 										\
 GType										\
 plugin_name##_get_type (void)							\
