@@ -34,7 +34,7 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
-#include <glib/gkeyfile.h>
+#include <glib.h>
 #include <gconf/gconf-client.h>
 
 #include "totem-plugin.h"
@@ -160,8 +160,8 @@ totem_plugins_engine_load (const gchar *file)
 	if (str && strcmp(str, "python") == 0) {
 		info->lang = TOTEM_PLUGIN_LOADER_PY;
 #ifndef ENABLE_PYTHON
-		g_debug ("Cannot load Python extension '%s', Totem was not "
-					"compiled with Python support", file);
+		g_warning ("Cannot load Python extension '%s', Totem was not compiled with Python support", file);
+		g_free (str);
 		goto error;
 #endif
 	} else {
@@ -375,7 +375,13 @@ totem_plugins_engine_init (TotemObject *totem)
 
 	totem_plugins_engine_load_all ();
 
-	garbage_collect_id = g_timeout_add_full (G_PRIORITY_LOW, 20000, garbage_collect_cb, NULL, NULL);
+#if 0
+#ifdef ENABLE_PYTHON
+	/* Commented out because it's a no-op. A further section is commented out below, and more's commented out
+	 * in totem-python-module.c. */
+	garbage_collect_id = g_timeout_add_seconds_full (G_PRIORITY_LOW, 20, garbage_collect_cb, NULL, NULL);
+#endif
+#endif
 
 	return TRUE;
 }
@@ -432,9 +438,13 @@ totem_plugins_engine_shutdown (void)
 		g_object_unref (totem_plugins_object);
 	totem_plugins_object = NULL;
 
+#if 0
+#ifdef ENABLE_PYTHON
 	if (garbage_collect_id > 0)
 		g_source_remove (garbage_collect_id);
 	totem_plugins_engine_garbage_collect ();
+#endif
+#endif
 
 	if (client != NULL)
 		g_object_unref (client);
@@ -504,7 +514,7 @@ load_plugin_module (TotemPluginInfo *info)
 #ifdef ENABLE_PYTHON
 			info->module = G_TYPE_MODULE (totem_python_module_new (info->file, info->location));
 #else
-			g_debug ("Cannot load plugin %s, Python plugin support is disabled", info->location);
+			g_warning ("Cannot load plugin %s, Python plugin support is disabled", info->location);
 #endif
 			break;
 	}
@@ -553,24 +563,27 @@ totem_plugins_engine_activate_plugin (TotemPluginInfo *info)
 {
 	char *msg;
 	GError *error = NULL;
+	gboolean ret;
 
 	g_return_val_if_fail (info != NULL, FALSE);
 
 	if (info->active)
 		return TRUE;
 
-	if (totem_plugins_engine_activate_plugin_real (info, totem_plugins_object, &error)) {
+	ret = totem_plugins_engine_activate_plugin_real (info, totem_plugins_object, &error);
+	if (info->visible != FALSE || ret != FALSE) {
 		char *key_name;
 
 		key_name = g_strdup_printf (GCONF_PLUGIN_ACTIVE, info->location);
-		gconf_client_set_bool (client, key_name, TRUE, NULL);
+		gconf_client_set_bool (client, key_name, ret, NULL);
 		g_free (key_name);
-
-		info->active = TRUE;
-
-		return TRUE;
 	}
 
+	info->active = ret;
+
+	if (ret != FALSE)
+		return TRUE;
+
 	if (error != NULL) {
 		msg = g_strdup_printf (_("Unable to activate plugin %s.\n%s"), info->name, error->message);
 		g_error_free (error);
