@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
@@ -255,16 +255,23 @@ totem_fullscreen_popup_hide (TotemFullscreen *fs)
 gboolean
 totem_fullscreen_motion_notify (GtkWidget *widget, GdkEventMotion *event,
 				TotemFullscreen *fs)
+{
+	totem_fullscreen_show_popups (fs, TRUE);
+	return FALSE;
+}
+
+void
+totem_fullscreen_show_popups (TotemFullscreen *fs, gboolean show_cursor)
 {
 	GtkWidget *item;
 
 	g_assert (fs->is_fullscreen != FALSE);
 
 	if (fs->priv->popup_in_progress != FALSE)
-		return FALSE;
+		return;
 
 	if (gtk_window_is_active (GTK_WINDOW (fs->priv->parent_window)) == FALSE)
-		return FALSE;
+		return;
 
 	fs->priv->popup_in_progress = TRUE;
 
@@ -281,15 +288,15 @@ totem_fullscreen_motion_notify (GtkWidget *widget, GdkEventMotion *event,
 	gtk_widget_show_all (fs->priv->exit_popup);
 	gtk_widget_show_all (fs->priv->control_popup);
 
-	/* Show the mouse cursor */
-	totem_fullscreen_set_cursor (fs, TRUE);
+	if (show_cursor != FALSE) {
+		/* Show the mouse cursor */
+		totem_fullscreen_set_cursor (fs, TRUE);
+	}
 
 	/* Reset the popup timeout */
 	totem_fullscreen_popup_timeout_add (fs);
 
 	fs->priv->popup_in_progress = FALSE;
-
-	return FALSE;
 }
 
 void
