@@ -170,7 +170,7 @@ totem_get_mount_for_media (const char *uri)
 	return ret;
 }
 
-static gboolean
+gboolean
 totem_is_special_mrl (const char *uri)
 {
 	GMount *mount;
@@ -260,6 +260,21 @@ static const char subtitle_ext[][4] = {
 	"ass"
 };
 
+gboolean
+totem_uri_is_subtitle (const char *uri)
+{
+	guint len, i;
+
+	len = strlen (uri);
+	if (len < 4 || uri[len - 4] != '.')
+		return FALSE;
+	for (i = 0; i < G_N_ELEMENTS (subtitle_ext); i++) {
+		if (g_str_has_suffix (uri, subtitle_ext[i]) != FALSE)
+			return TRUE;
+	}
+	return FALSE;
+}
+
 static inline gboolean
 totem_uri_exists (const char *uri)
 {
@@ -304,7 +319,7 @@ totem_uri_get_subtitle_for_uri (const char *uri)
 	g_return_val_if_fail (subtitle != NULL, NULL);
 	g_strlcpy (subtitle, uri, suffix + 4 + 1);
 	g_strlcpy (subtitle + suffix, ".???", 5);
-	
+
 	/* Search for any files with one of our known subtitle extensions */
 	for (i = 0; i < G_N_ELEMENTS (subtitle_ext) ; i++) {
 		memcpy (subtitle + suffix + 1, subtitle_ext[i], 3);
@@ -329,18 +344,18 @@ totem_uri_get_subtitle_in_subdir (GFile *file, const char *subdir)
 {
 	char *filename, *subtitle, *full_path_str;
 	GFile *parent, *full_path, *directory;
-  
+
 	/* Get the sibling directory @subdir of the file @file */
 	parent = g_file_get_parent (file);
 	directory = g_file_get_child (parent, subdir);
 	g_object_unref (parent);
-  
+
 	/* Get the file of the same name as @file in the @subdir directory */
 	filename = g_file_get_basename (file);
 	full_path = g_file_get_child (directory, filename);
 	g_object_unref (directory);
-  	g_free (filename);
-  
+	g_free (filename);
+
 	/* Get the subtitles from that URI */
 	full_path_str = g_file_get_uri (full_path);
 	g_object_unref (full_path);
@@ -350,6 +365,32 @@ totem_uri_get_subtitle_in_subdir (GFile *file, const char *subdir)
 	return subtitle;
 }
 
+static char *
+totem_uri_get_cached_subtitle_for_uri (const char *uri)
+{
+	char *basename, *fake_filename, *fake_uri, *ret;
+
+	basename = g_path_get_basename (uri);
+	if (basename == NULL || strcmp (basename, ".") == 0) {
+		g_free (basename);
+		return NULL;
+	}
+
+	fake_filename = g_build_filename (g_get_user_cache_dir (),
+				"totem",
+				"subtitles",
+				basename,
+				NULL);
+	g_free (basename);
+	fake_uri = g_filename_to_uri (fake_filename, NULL, NULL);
+	g_free (fake_filename);
+
+	ret = totem_uri_get_subtitle_for_uri (fake_uri);
+	g_free (fake_uri);
+
+	return ret;
+}
+
 char *
 totem_uri_get_subtitle_uri (const char *uri)
 {
@@ -370,6 +411,13 @@ totem_uri_get_subtitle_uri (const char *uri)
 		return NULL;
 	}
 
+	/* Try in the cached subtitles directory */
+	subtitle = totem_uri_get_cached_subtitle_for_uri (uri);
+	if (subtitle != NULL) {
+		g_object_unref (file);
+		return subtitle;
+	}
+
 	/* Try in the current directory */
 	subtitle = totem_uri_get_subtitle_for_uri (uri);
 	if (subtitle != NULL) {
@@ -502,7 +550,7 @@ totem_add_subtitle (GtkWindow *parent, const char *path)
 	char *subtitle = NULL;
 	gboolean set_folder;
 
-	fs = gtk_file_chooser_dialog_new (_("Select text subtitle"), 
+	fs = gtk_file_chooser_dialog_new (_("Select Text Subtitles"), 
 					  parent,
 					  GTK_FILE_CHOOSER_ACTION_OPEN,
 					  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
