@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
@@ -31,23 +31,18 @@
 
 #include <gtk/gtk.h>
 
-#ifndef HAVE_GTK_ONLY
-#include <gnome.h>
-#endif
-
 #include <bacon-video-widget.h>
-#include <glib/gthread.h>
+#include <glib.h>
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-init.h>
 #include <glib/gi18n.h>
 
 #include "totem-resources.h"
 #include "totem-mime-types.h"
 
 static gboolean show_mimetype = FALSE;
+static gboolean time_limit = TRUE;
 static gboolean g_fatal_warnings = FALSE;
 static char **filenames = NULL;
 
@@ -79,6 +74,7 @@ totem_print_string (BaconVideoWidget *bvw, const char *key, BaconVideoWidgetMeta
 	if (str != NULL) {
 		g_print ("%s=%s\n", key, str);
 	}
+	g_value_unset (&value);
 }
 
 static void
@@ -93,6 +89,7 @@ totem_print_int (BaconVideoWidget *bvw, const char *key, BaconVideoWidgetMetadat
 	if (num != 0) {
 		g_print ("%s=%d\n", key, num);
 	}
+	g_value_unset (&value);
 }
 
 static void
@@ -141,6 +138,7 @@ on_got_metadata_event (BaconVideoWidget *bvw, gpointer data)
 
 static const GOptionEntry entries[] = {
 	{"mimetype", 'm', 0, G_OPTION_ARG_NONE, &show_mimetype, "List the supported mime-types", NULL},
+	{ "no-limit", 'l', G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &time_limit, "Don't limit the thumbnailing time to 30 seconds", NULL },
 	{"g-fatal-warnings", 0, 0, G_OPTION_ARG_NONE, &g_fatal_warnings, "Make all warnings fatal", NULL},
 	{G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, "Movies to index", NULL},
 	{NULL}
@@ -167,11 +165,6 @@ int main (int argc, char **argv)
 	g_option_context_add_group (context, options);
 	g_type_init ();
 
-#ifndef HAVE_GTK_ONLY
-	gnome_authentication_manager_init ();
-#endif
-
-	gnome_vfs_init ();
 	if (g_option_context_parse (context, &argc, &argv, &error) == FALSE) {
 		g_print ("couldn't parse command-line options: %s\n", error->message);
 		g_error_free (error);
@@ -190,7 +183,10 @@ int main (int argc, char **argv)
 		print_mimetypes ();
 		return 0;
 	} else if (filenames == NULL || g_strv_length (filenames) != 1) {
-		g_print ("Expects exactly one URI\n");
+		char *help;
+		help = g_option_context_get_help (context, FALSE, NULL);
+		g_print ("%s", help);
+		g_free (help);
 		return 1;
 	}
 
@@ -206,7 +202,8 @@ int main (int argc, char **argv)
 			NULL);
 
 	path = filenames[0];
-	totem_resources_monitor_start (path, 0);
+	if (time_limit != FALSE)
+		totem_resources_monitor_start (path, 0);
 	if (bacon_video_widget_open (bvw, path, &error) == FALSE) {
 		g_print ("Can't open %s: %s\n", path, error->message);
 		return 1;
